@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 6)
+__version__ = (0, 0, 7)
 __all__ = [
     "create_cookie", "create_morsel", "cookie_to_morsel", "morsel_to_cookie", 
     "extract_cookies", "update_cookies", "cookies_str_to_dict", "cookies_dict_to_str", 
@@ -267,6 +267,8 @@ def update_cookies[Cookies: (CookieJar, SimpleCookie)](
     if isinstance(cookies1, CookieJar):
         if isinstance(cookies2, SimpleCookie):
             cookies: Iterable[Cookie | Morsel] = cookies2.values()
+        elif isinstance(cookies2, CookieJar):
+            cookies = cookies2
         elif isinstance(cookies2, Mapping):
             cookies = ValuesView(cookies2)
         else:
@@ -279,6 +281,8 @@ def update_cookies[Cookies: (CookieJar, SimpleCookie)](
     else:
         if isinstance(cookies2, SimpleCookie):
             morsels: Iterable[tuple[str, Morsel]] = cookies2.items()
+        elif isinstance(cookies2, CookieJar):
+            morsels = ((cookie.name, cookie_to_morsel(cookie)) for cookie in cookies2)
         elif isinstance(cookies2, Mapping):
             morsels = ((k, v if isinstance(v, Morsel) else cookie_to_morsel(v)) for k, v in ItemsView(cookies2))
         else:
